[PATCH] input: wm97xx - update email address for Liam Girdwood

From: Liam Girdwood
Date: Sun Oct 12 2008 - 08:28:19 EST


This updates the email address for Liam Girdwood as my old address is no
longer valid.

Signed-off-by: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
---
MAINTAINERS | 2 +-
drivers/input/touchscreen/mainstone-wm97xx.c | 5 ++---
drivers/input/touchscreen/wm9705.c | 5 ++---
drivers/input/touchscreen/wm9712.c | 5 ++---
drivers/input/touchscreen/wm9713.c | 5 ++---
drivers/input/touchscreen/wm97xx-core.c | 5 ++---
6 files changed, 11 insertions(+), 16 deletions(-)

diff --git a/MAINTAINERS b/MAINTAINERS
index 587f418..ca5f4f6 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -4591,7 +4591,7 @@ WM97XX TOUCHSCREEN DRIVERS
P: Mark Brown
M: broonie@xxxxxxxxxxxxxxxxxxxxxxxxxxx
P: Liam Girdwood
-M: liam.girdwood@xxxxxxxxxxxxxxxx
+M: lrg@xxxxxxxxxxxxxxx
L: linux-input@xxxxxxxxxxxxxxx
T: git git://opensource.wolfsonmicro.com/linux-2.6-touch
W: http://opensource.wolfsonmicro.com/node/7
diff --git a/drivers/input/touchscreen/mainstone-wm97xx.c b/drivers/input/touchscreen/mainstone-wm97xx.c
index 37a555f..ba64875 100644
--- a/drivers/input/touchscreen/mainstone-wm97xx.c
+++ b/drivers/input/touchscreen/mainstone-wm97xx.c
@@ -3,8 +3,7 @@
* Wolfson WM97xx AC97 Codecs.
*
* Copyright 2004, 2007 Wolfson Microelectronics PLC.
* Author: Liam Girdwood
* liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
*
@@ -296,6 +295,6 @@ module_init(mainstone_wm97xx_init);
module_exit(mainstone_wm97xx_exit);

/* Module information */
-MODULE_AUTHOR("Liam Girdwood <liam.girdwood@xxxxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Liam Girdwood <lrg@xxxxxxxxxxxxxxx>");
MODULE_DESCRIPTION("wm97xx continuous touch driver for mainstone");
MODULE_LICENSE("GPL");
@@ -3,8 +3,7 @@
*
* Copyright 2004, 2007 Wolfson Microelectronics PLC.
- * Author: Liam Girdwood
- * liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
+ * Author: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
diff --git a/drivers/input/touchscreen/wm9705.c b/drivers/input/touchscreen/wm9705.c
index 372efbc..6b5be74 100644
--- a/drivers/input/touchscreen/wm9705.c
+++ b/drivers/input/touchscreen/wm9705.c
@@ -2,8 +2,7 @@
* wm9705.c -- Codec driver for Wolfson WM9705 AC97 Codec.
*
* Copyright 2003, 2004, 2005, 2006, 2007 Wolfson Microelectronics PLC.
* Author: Liam Girdwood
* liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
* Russell King <rmk@xxxxxxxxxxxxxxxx>
@@ -347,6 +346,6 @@ struct wm97xx_codec_drv wm9705_codec = {
EXPORT_SYMBOL_GPL(wm9705_codec);

/* Module information */
-MODULE_AUTHOR("Liam Girdwood <liam.girdwood@xxxxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Liam Girdwood <lrg@xxxxxxxxxxxxxxx>");
MODULE_DESCRIPTION("WM9705 Touch Screen Driver");
MODULE_LICENSE("GPL");
@@ -2,8 +2,7 @@
*
* Copyright 2003, 2004, 2005, 2006, 2007 Wolfson Microelectronics PLC.
- * Author: Liam Girdwood
- * liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
+ * Author: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
diff --git a/drivers/input/touchscreen/wm9712.c b/drivers/input/touchscreen/wm9712.c
index c8bb1e7..7490b05 100644
--- a/drivers/input/touchscreen/wm9712.c
+++ b/drivers/input/touchscreen/wm9712.c
@@ -2,8 +2,7 @@
* wm9712.c -- Codec driver for Wolfson WM9712 AC97 Codecs.
*
* Copyright 2003, 2004, 2005, 2006, 2007 Wolfson Microelectronics PLC.
* Author: Liam Girdwood
* liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
* Russell King <rmk@xxxxxxxxxxxxxxxx>
@@ -462,6 +461,6 @@ struct wm97xx_codec_drv wm9712_codec = {
EXPORT_SYMBOL_GPL(wm9712_codec);

/* Module information */
-MODULE_AUTHOR("Liam Girdwood <liam.girdwood@xxxxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Liam Girdwood <lrg@xxxxxxxxxxxxxxx>");
MODULE_DESCRIPTION("WM9712 Touch Screen Driver");
MODULE_LICENSE("GPL");
@@ -2,8 +2,7 @@
*
* Copyright 2003, 2004, 2005, 2006, 2007 Wolfson Microelectronics PLC.
- * Author: Liam Girdwood
- * liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
+ * Author: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
diff --git a/drivers/input/touchscreen/wm9713.c b/drivers/input/touchscreen/wm9713.c
index 781ee83..238b513 100644
--- a/drivers/input/touchscreen/wm9713.c
+++ b/drivers/input/touchscreen/wm9713.c
@@ -2,8 +2,7 @@
* wm9713.c -- Codec touch driver for Wolfson WM9713 AC97 Codec.
*
* Copyright 2003, 2004, 2005, 2006, 2007, 2008 Wolfson Microelectronics PLC.
* Author: Liam Girdwood
* liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
* Russell King <rmk@xxxxxxxxxxxxxxxx>
@@ -476,6 +475,6 @@ struct wm97xx_codec_drv wm9713_codec = {
EXPORT_SYMBOL_GPL(wm9713_codec);

/* Module information */
-MODULE_AUTHOR("Liam Girdwood <liam.girdwood@xxxxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Liam Girdwood <lrg@xxxxxxxxxxxxxxx>");
MODULE_DESCRIPTION("WM9713 Touch Screen Driver");
MODULE_LICENSE("GPL");
@@ -2,8 +2,7 @@
*
* Copyright 2003, 2004, 2005, 2006, 2007, 2008 Wolfson Microelectronics PLC.
- * Author: Liam Girdwood
- * liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
+ * Author: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
diff --git a/drivers/input/touchscreen/wm97xx-core.c b/drivers/input/touchscreen/wm97xx-core.c
index d589ab0..d15aa11 100644
--- a/drivers/input/touchscreen/wm97xx-core.c
+++ b/drivers/input/touchscreen/wm97xx-core.c
@@ -3,8 +3,7 @@
* and WM9713 AC97 Codecs.
*
* Copyright 2003, 2004, 2005, 2006, 2007, 2008 Wolfson Microelectronics PLC.
* Author: Liam Girdwood
* liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
* Russell King <rmk@xxxxxxxxxxxxxxxx>
@@ -824,6 +823,6 @@ module_init(wm97xx_init);
module_exit(wm97xx_exit);

/* Module information */
-MODULE_AUTHOR("Liam Girdwood <liam.girdwood@xxxxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Liam Girdwood <lrg@xxxxxxxxxxxxxxx>");
MODULE_DESCRIPTION("WM97xx Core - Touch Screen / AUX ADC / GPIO Driver");
MODULE_LICENSE("GPL");
@@ -3,8 +3,7 @@
*
* Copyright 2003, 2004, 2005, 2006, 2007, 2008 Wolfson Microelectronics PLC.
- * Author: Liam Girdwood
- * liam.girdwood@xxxxxxxxxxxxxxxx or linux@xxxxxxxxxxxxxxxx
+ * Author: Liam Girdwood <lrg@xxxxxxxxxxxxxxx>
* Parts Copyright : Ian Molton <spyro@xxxxxxx>
* Andrew Zabolotny <zap@xxxxxxxxxxx>
--
1.5.4.3


--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/